@@ -1,6 +1,6 @@
-from src.arkclient.format.stream import Stream
-from src.arkclient.format.header import Header
-from src.arkclient.lib.configuration import Ini
+from arkclient.format.stream import Stream
+from arkclient.format.header import Header
+from arkclient.lib.configuration import Ini
 import socket
 from pathlib import Path
 
