@@ -2,11 +2,6 @@ from arkclient.client import GameBotClient
 from time import sleep
 
 
-def run():
-    pass
-
-
-
 def test():
     with GameBotClient("bot") as bot:
         for i in range(3):
